# Access game API documentation

**Introduction**: ASTAR Video game docking document

**Contact person**: ASTAR

**Version**: 3.0

**Describe**:<p>The platform provides service addresses and API interfaces for third-party access.</p>

**Preparation**

1. Business commissioner docking, obtaining channel code (channel) and key(apiKey).
2. Join the Telegram docking group to get help and support.

**Access process**

1. **Authentication**: Use the provided channel code (channel) and key (apiKey) for authentication to ensure the legitimacy of the request.
2. **Create user**: To create a user account on the gaming platform, you usually need to provide some necessary user information.
3. **Log in game**: Use the created user account to login to the game and obtain the log in game’s address.
4. **Deposit**: In game, users recharge or deposit, and points are transferred to the game account.
5. **Play game**: Users perform game operations, according to game rules.
6. **Withdraw**: In game, Users withdraw bonus and balance to platform account, points are lower.
7. **Pull bet**: In game, obtain the user's betting records for subsequent data statistics and analysis.

## Authentication

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/auth?apiKey={apiKey}`

**Describe**:<p>For access party calls,Get security token,**After filling in the request header, you can access subsequent interfaces(The token obtained each time is the same, so you only need to request it once)**,HTTP The request header needs to be added Authorization parameter, Authorization: Bearer+space+token,No Authorization parameter: HTTP-400 error, Authorization Parameter error: HTTP-403 error</p>

**code example**:

```javascript
{
    HttpHeaders headers = new HttpHeaders();
	headers.setBearerAuth(token);
    //Same effect headers.setBearerAuth(token);
    //headers.add("Authorization", "Bearer " + token);
    headers.setAccept(Collections.singletonList(MediaType.APPLICATION_JSON));
    RequestEntity<Void> entity = RequestEntity.method(HttpMethod.GET, uri).headers(headers).build();
    ResponseEntity<Result> resp = restTemplate.exchange(entity, Result.class);
}
```

**Request parameters**:

| Name   | Description | Type   | Describe | Need |
| :----- | ----------- | ------ | -------- | ---- |
| apiKey | passkey     | string | passkey  | true |

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | token                     | string | token                                        |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "eyJhb9.eyJRmZGY4In0.vRP4-t4yVpaTL-u99JD7-byM1YYdTb_v_Blp27I_4_n-lDqA"
}
```

## Create user

**Request method**:`POST`

**Address**:`https://<server>/channelApi/V3/API/{channel}/createUser`

**Request data type**:`application/json`

**Response data type**:`application/json`

**Interface description**:<p>For access party calls,Create user account</p>

**Request parameters**:

| Name     | Description           | Type   | Describe                                                     | Need  |
| -------- | --------------------- | ------ | ------------------------------------------------------------ | ----- |
| userName | user name             | string | the length of the member account is recommended to be**[4,64]**between characters,It can only be a combination of letters, numbers, and underscores, not to include special characters. | true  |
| currency | [currency](#CURRENCY) | string | currency type, default is CNY,If multiple players belong to the same agent,then their currency is the same, and the currency is defined at the agent level. | false |
| agent    | agent                 | string | the agent to which the member belongs,When no agency setting  doesn't need. to pass, the length is 4~10 between characters, consisting of letters、number and Underlined. | false |

**Request example**:

```javascript
{
 	"userName":"X9528",
    "currency":"CNY",
    "agent":"DT_AGENT"
}
```

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | user                      | user   | user info                                    |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "channel": "DT",
        "agent": "DT_AGENT",
        "balance": "0.00",
        "currency": "CNY"
    }
}
```

## Login game

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/loginWithChannel?userName={userName}`

**Describe**:<p>For access party calls,Get login game’s link,If you need to enter the lobby directly, please add the parameter &lobbyId={lobbyId} after the login link, if you need to enter the table directly, please splice the parameter &tableId={tableId} after the login link.</p>

**Request parameters**:

| Name     | Description | Type   | Describe                                                     | Need  |
| -------- | ----------- | ------ | ------------------------------------------------------------ | ----- |
| userName | user name   | string | user name                                                    | true  |
| language | language    | string | Support Chinese (default): zh-cn <br/>Traditional: zh-tw<br/>English: en-us<br/>Korean: ko-kr<br/>Thai: th-th<br/>Vietnam :vi-vn<br/>Brazilian-Portuguese:pt-br<br/>Indonesia:hi-in | false |

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | URL                       | string | login game link                              |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "https://***.0***666.com?token=CB0FC676B4***993&language=zh-cn"
}
```

## Login Game 2 (chess, electronic)

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/loginWithPlayType?userName={userName}&playType={playType}&gameId={gameId}`

**Describe**:<p>For access parties to call, get the links for chess, electronic game logins.</p>

**Request parameters**:

| Name     | Description | Type   | Describe                                                     | Need  |
| -------- | ----------- | ------ | ------------------------------------------------------------ | ----- |
| userName | user name   | string | user name                                                    | true  |
| language | language    | string | Support Chinese (default): zh-cn <br/>Traditional: zh-tw<br/>English: en-us<br/>Korean: ko-kr<br/>Thai: th-th<br/>Vietnam :vi-vn<br/>Brazilian-Portuguese:pt-br<br/>Indonesia:hi-in | false |
| playType | play type   | int    | Game type,  4: Chess 5: Fishing                              | true  |
| gameId   | game id     | int    | gameId refers to the table ID (Room ID) in the 'Astar Game List'. When the game type is live (playType = 1), this parameter can be set to 0 or omitted              | true |

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | URL                       | string | login game link                              |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "https://***.0***666.com?token=CB0FC676B4***993&language=zh-cn"
}
```

## User logout

**Request method**:`POST`

**Address**:`https://<server>/channelApi/V3/API/{channel}/logout`

**Request data type**:`application/json`

**Response data type**:`application/json`

**Interface description**:<p>For access party calls,User logout</p>

**Request parameters**:

| Name     | Description    | Type   | Describe                                      | Need |
| -------- |----------------| ------ |-----------------------------------------------| ---- |
| userName | user name      | string | user name                                     | true |
| isKick   | is kicked      | boolean| Used to kick users offline(toast：please log in again) | false |

**Request example**:

```javascript
{
    "userName":"X9528",
    "isKick":true
}
```

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | value                     |        |                                              |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": null
}
```

## User deposit

**Request method**:`POST`

**Address**:`https://<server>/channelApi/V3/API/{channel}/deposit`

**Request data type**:`application/json`

**Response data type**:`application/json`

**Interface description**:<p>For access party calls,User deposit</p>

**Request parameters**:

| Name     | Description  | Type   | Describe                                                     | Need |
| -------- | ------------ | ------ | ------------------------------------------------------------ | ---- |
| userName | user name    | string | user name                                                    | true |
| amount   | amount       | string | amount,Greater than 0, and can only retain 2 decimal places, and a single deposit is less than 2 million RMB (2 million RMB after conversion of other currency exchange rates) | true |
| serial   | order number | string | the unique order number created by the operating platform,Used for uniqueness judgment,Rule: channel number+deposit+random numbers or letters,Length no more than 64 characters | true |

**Request example**:

```javascript
{
    "userName":"X9528",
    "amount":1000,
    "serial":"DTdeposit231011090333"
}
```

**Response parameters**:

| Name    | Description               | Type    | Describe                                     |
| ------- | ------------------------- | ------- | -------------------------------------------- |
| state   | [State code](#State code) | int     | 0 indicates success, others indicate failure |
| message | message                   | string  |                                              |
| value   | balance                   | balance | balance information                          |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "channel": "DT",
        "agent": "DT-AGENT",
        "balance": "1000.00",
        "currency": "CNY"
    }
}
```

## User withdrawals

**Request method**:`POST`

**Address**:`https://<server>/channelApi/V3/API/{channel}/withdraw`

**Request data type**:`application/json`

**Response data type**:`application/json`

**Interface description**:<p>For access party calls, User withdrawals</p>

**Request parameters**:

| Name     | Description  | Type   | Describe                                                     | Need |
| -------- | ------------ | ------ | ------------------------------------------------------------ | ---- |
| userName | user name    | string | user name                                                    | true |
| amount   | amount       | string | amount,Greater than 0, and can only retain 2 decimal places, and a single withdraw is less than 2 million RMB (2 million RMB after conversion of other currency exchange rates) | true |
| serial   | order number | string | the unique order number created by the operating platform,Used for uniqueness judgment,<br>Rule: chanel number+withdraw+random numbers or letters,Length no more than 64 characters | true |

**Request example**:

```javascript
{
    "userName":"X9528",
    "amount":500,
    "serial":"DTwithdraw231011090333"
}
```

**Response parameters**:

| Name    | Description               | Type    | Describe                                     |
| ------- | ------------------------- | ------- | -------------------------------------------- |
| state   | [State code](#State code) | int     | 0 indicates success, others indicate failure |
| message | message                   | string  |                                              |
| value   | balance                   | balance | balance information                          |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "channel": "DT",
        "agent": "DT-AGENT",
        "balance": "500.00",
        "currency": "CNY"
    }
}
```

## Get user deposit and withdrawal records

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getTrans?userName={userName}`

`&serial={serial}`

**Describe**:<p>For access party calls,Obtain user deposit and withdrawal records</p>

**Request parameters**:

| Name     | Description  | Type   | Describe                                                     | Need |
| -------- | ------------ | ------ | ------------------------------------------------------------ | ---- |
| userName | user name    | string | user name                                                    | true |
| serial   | order number | string | the unique order number created by the operating platform,Used for uniqueness judgment,<br/>Rule: chanel number+deposit+random numbers or letters,Length no more than 64 characters | true |

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | record                    | record | deposit and withdrawal information           |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "DTX9528",
        "serail": "DTdeposit231011101133",
        "beforeBalance": 1000.0,//balance before transfer
        "dealBalance": 1000.0,//transfer amount
        "afterBalance": 2000.0,//amount after transfer
        "changeTime": "2023-10-11 14:11:51",
        "currency": "CNY"
    }
}
```

## Get channel deposit and withdrawal records

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getTransList?startTime={startTime}&endTime={endTime}&pageIndex={pageIndex}&pageSize={pageSize}`

**Describe**:<p>For access party calls,Obtain channel deposit and withdrawal records</p>

**Request parameters**:

| Name      | Description                               | Type   | Describe                                                     | Need  |
| --------- | ----------------------------------------- | ------ | ------------------------------------------------------------ | ----- |
| startTime | start time                                | string | Start time, date format yyyy-MM-dd HH:mm:ss                  | true  |
| endTime   | end time                                  | string | End time, date format yyyy-MM-dd HH:mm:ss,<br/>The start time~end time range is within 7 days, <br/>and the earliest supported query is 2 months of data | true  |
| pageIndex | Page number, default 1                    | int    | page index                                                   | false |
| pageSize  | Number of pages, default 200, range 0~200 | int    | page size                                                    | false |

**Response parameters**:

| Name    | Description               | Type         | Describe                                     |
| ------- | ------------------------- | ------------ | -------------------------------------------- |
| state   | [State code](#State code) | int          | 0 indicates success, others indicate failure |
| message | message                   | string       |                                              |
| value   | transRecords              | transRecords | deposit and withdrawal information           |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "total": 2,
        "transRecords": [
            {
                "userName": "DTX9528",
                "agentName": "DT-AGENT",
                "serial": "DTdeposit241011101133",
                "code": "deposite",
                "amount": 200000.0,
                "opTime": "2024-06-10 15:15:08"
            },
            {
                "userName": "DTX9528",
                "agentName": "DT-AGENT",
                "serial": "DTwithdraw231011101133",
                "code": "withdraw",
                "amount": -100.0,
                "opTime": "2024-06-10 15:15:24"
            }
        ],
        "pageIndex": 1,
        "currPageSize": 2,
        "pageSize": 200
    }
}
```

## Get account balance

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getBalance?userName={userName}`

**Describe**:<p>For access party calls, Get account balance</p>

**Request parameters**:

| Name     | Description | Type   | Describe  | Need |
| -------- | ----------- | ------ | --------- | ---- |
| userName | user name   | string | user name | true |

**Response parameters**:

| Name    | Description               | Type    | Describe                                     |
| ------- | ------------------------- | ------- | -------------------------------------------- |
| state   | [State code](#State code) | int     | 0 indicates success, others indicate failure |
| message | message                   | string  |                                              |
| value   | balance                   | balance | balance information                          |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "channel": "DT",
        "agent": "DT-AGENT",
        "balance": "500.00",
        "currency": "CNY",
        "limit": "CA,CB,CC"
    }
}
```

## Get account balance in batches

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getBalanceBatch?userNames={userNames}`

**Describe**:<p>For access party calls,Get account balance in batches</p>

**Request parameters**:

| Name      | Description               | Type   | Describe  | Need |
| --------- | ------------------------- | ------ | --------- | ---- |
| userNames | user name,use"," separate | string | user name | true |

**Response parameters**:

| Name    | Description               | Type    | Describe                                     |
| ------- | ------------------------- | ------- | -------------------------------------------- |
| state   | [State code](#State code) | int     | 0 indicates success, others indicate failure |
| message | message                   | string  |                                              |
| value   | balance                   | balance | balance information                          |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": [
        {
            "userName": "X9528",
            "balance": 1500.0,
            "limit": "CA,CB,CC"
        }
    ]
}
```

## Get account balance list - account balance is greater than the set amount

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getBalanceList?amount={amount}`

**Describe**:<p>Called by the access party to obtain the account balance list</p>

**Request parameters**:

| Name      | Description            | Type   | Describe    | Need  |
| --------- | ---------------------- | ------ | ----------- | ----- |
| pageIndex | Page number, default 1 | int    | page number | false |
| amount    | Amount, default 0      | double | Amount      | false |

**Response example**:

| Name    | Description               | Type    | Describe                                     |
| ------- | ------------------------- | ------- | -------------------------------------------- |
| state   | [State code](#State code) | int     | 0 indicates success, others indicate failure |
| message | message                   | string  |                                              |
| value   | balance                   | balance | balance information                          |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "total": 1577,
        "records": [
            {
                "userName": "X9528",
                "amount": 9997,
                "limit": "CA,CB,CC"
            }
        ],
        "pageIndex": 1,
        "currPageSize": 1000,
        "pageSize": 1000
    }
}
```

## Get user available status

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getUserAvailable?userName={userName}`

**Describe**:<p>For access party calls,Get user available status</p>

**Request parameters**:

| Name     | Description | Type   | Describe  | Need |
| -------- | ----------- | ------ | --------- | ---- |
| userName | user name   | string | user name | true |

**Response parameters**:

| Name    | Description               | Type      | Describe                                                     |
| ------- | ------------------------- | --------- | ------------------------------------------------------------ |
| state   | [State code](#State code) | int       | 0 indicates success, others indicate failure                 |
| message | message                   | string    |                                                              |
| value   | available                 | available | available: 0: normal; 1: betting prohibited <br>2: deactivate account |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "available": 0
    }
}
```

## Set user available status

**Request method**:`POST`

**Address**:`https://<server>/channelApi/V3/API/{channel}/setUserAvailable`

**Request data type**:`application/json`

**Response data type**:`application/json`

**Interface description**:<p>For access party calls,Set user available status</p>

**Request parameters**:

| Name      | Description | Type   | Describe                                                    | Need |
| --------- | ----------- | ------ | ----------------------------------------------------------- | ---- |
| userName  | user name   | string | user name                                                   | true |
| available | available   | int    | 0: normal; 1: betting prohibited <br/>2: deactivate account | true |

**Request example**:

```javascript
{
    "userName":"X9528",
    "available":0
}
```

**Response parameters**:

| Name    | Description               | Type      | Describe                                                     |
| ------- | ------------------------- | --------- | ------------------------------------------------------------ |
| state   | [State code](#State code) | int       | 0 indicates success, others indicate failure                 |
| message | message                   | string    |                                                              |
| value   | available                 | available | available: 0: Normal; 1: Login prohibited; 2: Betting prohibited |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "available": 0
    }
}
```

## Set limits

**Request method**:`POST`

**Address**:`https://<server>/channelApi/V3/API/{channel}/setUserLimit`

**Request data type**:`application/json`

**Response data type**:`application/json`

**Interface description**:<p>For access party calls,Set user betting limit</p>

**Request parameters**:

| Name     | Description          | Type   | Describe                                                                                                                                                       | Need |
| -------- |----------------------| ------ |----------------------------------------------------------------------------------------------------------------------------------------------------------------| ---- |
| userName | user name            | string | user name(If `isAgent` is true, it is the `userName` of the agent, if `isAgent` is false or this parameter is not passed, it is the `userName` of the member.) | true |
| limit    | limit                | string | CA: 10-1000,CB: 10-10000,CC: 10-30000,CD: 10-50000,CE: 10-100000,CF: 10-150000,CG: 10-200000,Parameters are separated by","                                    | true |
| isAgent  | AgentAccount or not  | boolean | Whether it is a agent account, true to modify the agent `limit`, false to modify the member `limit`(default vaule:false)                                       | false |

**Request example**:

1.modify the member limit
```javascript
{
    "userName":"X9528",
    "limit":"CA,CB,CC"
}
```
2.modify the agent limit
```javascript
{
    "userName":"X9528",
    "limit":"CA,CB,CC",
    "isAgent":true
}
```

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | quota                     | string | quota information                            |

**Response example**:

```javascript
{
    "state": 0,
        "message": "成功",
        "value": [
        {
            "id": 31892,
            "parentid": 18354,
            "parentclass": "com.fontana.wraper.UserWraper",
            "name": "CA",
            "type": 0
        }
    ]
}
```

## Create Agent

**Request method**:`POST`

**Address**:`https://<server>/channelApi/V3/API/{channel}/createAgent`

**Request data type**:`application/json`

**Response data type**:`application/json`

**Interface description**:<p>For access party calls,Create user account</p>

**Request parameters**:

| Name     | Description           | Type   | Describe                                                                                                                                                                                | Need  |
| -------- |-----------------------| ------ |-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------| ----- |
| agentName| agent name            | string | the length of the member account is recommended to be**[4,64]**between characters,It can only be a combination of letters, numbers, and underscores, not to include special characters. | true  |
| currency | [currency](#CURRENCY) | string | currency type, default is CNY,If multiple players belong to the same agent,then their currency is the same, and the currency is defined at the agent level.                             | false |
| limit    | limit                 | string | CA: 10-1000,CB: 10-10000,CC: 10-30000,CD: 10-50000,CE: 10-100000,CF: 10-150000,CG: 10-200000,Parameters are separated by","(default: company limit)                                     | false |

**Request example**:

```javascript
{
    "agentName":"X9528",
    "currency":"CNY",
    "limit":"CA,CB,CC"
}
```

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | user                      | user   | user info                                    |

**Response example**:

```javascript
{
    "state": 0,
        "message": "成功",
        "value": {
        "agentName": "X9528",
        "channel": "DT",
        "balance": "0.00",
        "limit": "CA,CB,CC",
        "currency": "CNY"
    }
}
```

## Get user online status

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getUserOnlineState?userName={userName}`

**Describe**:<p>For access party calls,Get user online status</p>

**Request parameters**:

| Name     | Description | Type   | Describe  | Need |
| -------- | ----------- | ------ | --------- | ---- |
| userName | user name   | string | user name | true |

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | online                    | int    | 0: not on-line; 1: on-line                   |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "online": 0
    }
}
```

## Get channel online user

**Request metho**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getChannelOnlineList`

**Describe**:<p>For access party calls,Get chennel online user</p>

**Request parameters**:

**Response parameters**:

| Name    | Description               | Type       | Describe                                                     |
| ------- | ------------------------- | ---------- | ------------------------------------------------------------ |
| state   | [State code](#State code) | int        | 0 indicates success, others indicate failure                 |
| message | message                   | string     |                                                              |
| value   | onlineUser                | onlineUser | location,0-Lobby, 1-Baccarat, 2-Dragon Tiger, 3-Roulette, 4-Sic Bo, 5-Niu Niu, 6-Texas Hold'em, 7-Zhajinhua |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": [
        {
            "userName": "b6945c00018aead2",
            "location": 1
        }
    ]
}
```

## Get user bet record link

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getBetInfoDetailLink?betId={betId}&lang={lang}`

**Describe**:<p>For the access party to call,get the user's bet details link</p>

**Request parameters**:

| Name  | Description | Type   | Describe                                                     | Need  |
| ----- | ----------- | ------ | ------------------------------------------------------------ | ----- |
| betId | bet ID      | long   | bet ID                                                       | true  |
| lang  | language    | String | Support Chinese (default): zh-cn <br/>Traditional: zh-tw<br/>English: en-us | false |

**Response parameters**:

| Name    | Description           | Type   | Describe                                     |
| ------- | --------------------- | ------ | -------------------------------------------- |
| state   | [State code](#状态码) | int    | 0 indicates success, others indicate failure |
| message | message               | string |                                              |
| value   | link                  | string | bet detail url                               |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "https://***.0***666.com/history_detail/index.html?token=8CuyZd2N6U1StTM5Ocy3&language=zh-cn&betId=13213&channel=LP"
}
```

## Get user Block chain game bet detail url

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getHashBetDetailUrl?recordId={recordId}&lang={lang}`

**Describe**:<p>Called by the access party to obtain the user's Block chain game bet details link</p>

**Request parameters**:

| Name     | Description | Type                                                         | Describe | Need  |
| -------- | ----------- | ------------------------------------------------------------ | -------- | ----- |
| recordId | bet id      | long                                                         | bet id   | true  |
| lang     | language    | StringSupport Chinese (default): zh-cn <br/>Traditional: zh-tw<br/>English: en-us<br/>Korean: ko-kr<br/>Thai: th-th<br/>Vietnam :vi-vn<br/> | language | false |

**Response parameters**:

| Name    | Description           | Type   | Describe                                     |
| ------- | --------------------- | ------ | -------------------------------------------- |
| state   | [State code](#状态码) | int    | 0 indicates success, others indicate failure |
| message | message               | string |                                              |
| value   | url                   | string | hash game bet detail url                     |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "value": "https://<server>/bet_info.html?merchant_id=*&desk_id=*&game_id=*&order_id=*&lang=zh-	hans&token=eyJhbGci**"
}
```

## Get user  Board game bet detail url

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getBetDetailUrl?recordId={recordId}&lang={lang}`

**Describe**:<p>Called by the access party to obtain the user's board game bet details link</p>

**Request parameters**:

| Name     | Description | Type                                                         | Describe | Need  |
| -------- | ----------- | ------------------------------------------------------------ | -------- | ----- |
| recordId | bet id      | long                                                         | bet id   | true  |
| lang     | language    | StringSupport Chinese (default): zh-cn <br/>Traditional: zh-tw<br/>English: en-us<br/>Korean: ko-kr<br/>Thai: th-th<br/>Vietnam :vi-vn<br/> | language | false |

**Response parameters**:

| Name    | Description           | Type   | Describe                                     |
| ------- | --------------------- | ------ | -------------------------------------------- |
| state   | [State code](#状态码) | int    | 0 indicates success, others indicate failure |
| message | message               | string |                                              |
| value   | url                   | string | hash game bet detail url                     |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "value": ""https://<server>/ChannelApi/API/VG/GetGameResultBox?uid=28*****8&gametype=1&datatype=1"
}
```

## Get a summary of user bet records

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getRecordTotalByTime?startTime={startTime}&endTime={endTime}&agentName={agentName}`

**Describe**:<p>For the access party to call, get the bet data summary by time period [getRecordTotalByTime]. This interface is only allowed to be called 2 times in 10 seconds.</p>

**Request parameters**:

| Name      | Description                                                  | Type   | Describe   | Need  |
| --------- | ------------------------------------------------------------ | ------ | ---------- | ----- |
| startTime | Start time,date format "yyyy-MM-dd HH:mm:ss"                 | string | start time | true  |
| endTime   | End time,date format "yyyy-MM-dd HH:mm:ss"<br/>The start time~end time range is within 31 days | string | end time   | true  |
| agentName | agent name                                                   | string | agent name | false |

**Response parameters**:

| Name    | Description               | Type   | Describe                                     |
| ------- | ------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code) | int    | 0 indicates success, others indicate failure |
| message | message                   | string |                                              |
| value   | total                     | total  | Summary of bet records                       |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "totalOrder": 187,//Total bet odds
        "totalBetAmount": 266208.0,//Total bet amount
        "totalCommAmount": 219764.1,//Total wash amount
        "totalResultAmount": -38914.9//Total win and loss amount
    }
}
```



## Obtain user's bet record (recommended)

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getRecordByCondition?startTime={startTime}&endTime={endTime}&agentName={agentName}&correctTime={correctTime}&pageIndex={pageIndex}&pageSize={pageSize}&version={version}`

**Describe**:<p>For access party calls,Get bets by time period[getRecordByCondition],All bets within this time period will be returned in paginated form,The first page number starts from 1,The total number of items in this time period will be returned each time. This interface is only allowed to be used 10 times every 10 seconds,A maximum of 200 pieces of data are returned each time,correctTime is end time for the last piece of data pulled,It needs to be updated every time a bet is pulled within the same period correctTime.</p>

**Request parameters**:

| Name        | Description                                                  | Type   | Describe        | Need  |
| ----------- | ------------------------------------------------------------ | ------ | --------------- | ----- |
| startTime   | Start time,date format "yyyy-MM-dd HH:mm:ss"support recent One month of data,<br/> spaces need to be escaped as %20 | string | start time      | true  |
| endTime     | End time,date format "yyyy-MM-dd HH:mm:ss"<br/>Start time~End time range is within 24 hour,<br/> spaces need to be escaped as %20 | string | end time        | true  |
| agentName   | agent name                                                   | string | agent name      | false |
| correctTime | settlement time,date format "yyyy-MM-dd HH:mm:ss",Pull bet data Settlement time of the last piece of data, the first time of Pulling data,The value is set to the start time, spaces need to be escaped as %20 | string | settlement time | true  |
| pageIndex   | Page number, default 1                                       | int    | page number     | false |
| pageSize    | size of pages, default 100,range 0~200                       | int    | page size       | false |
| version     | version，default value 3.0：Live video bet record，3.1：Live video、Live broadcast、 Block chain bet record、Chess bet record、 fishing bet record | string | version         | false |

**Response parameters**:

| Name    | Description                                              | Type   | Describe                                     |
| ------- | -------------------------------------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code)                                | int    | 0 indicates success, others indicate failure |
| message | message                                                  | string |                                              |
| value   | [game records](#Detailed explanation of Bet slip fields) | bets   | bet records                                  |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "gameRecords": [
            {
                "id": 415,
                "userName": "DT6501050d0dbe5769a97cad88",
                "channel": "DT",
                "agent": "621829689c133400019eb38d",
                "createTime": "2023-09-13 08:42:27",
                "gameType": 1,
                "tableId": "41",
                "roundId": "60749966",
                "betAmount": 10.0,
                "validBetAmount": 10.0,
                "betPoint": "PLAYER:10.00@10.00@10.00#",
                "odds": null,
                "money": 10.0,
                "serviceMoney": null,
                "beginTime": "2023-09-13 08:41:52",
                "endTime": "2023-09-13 08:42:47",
                "groupFor": "2023-09-12",
                "isBanker": 0,
                "gameInfo": "12-3-0;6-3-1;7-2-2;4-2-3;0-0-4;2-3-5",
                "gameResult": "PLAYER",
                "beforeBalance": null,
                "status": "A",
                "info1": null,
                "jp": 0,
                "enterType": 0,
                "shoeNum": 18,
                "gamblingNum": 19,
                "ip": "18.139.29.99",
                "currency": "CNY",
                "recordId": 1527397,//version 3.1
                "playType": 1 //version 3.1
            }
        ],
        "lastRecordId": 5962,
        "total": 1,
        "pageIndex": 1,
        "currPageSize": 1,
        "pageSize": 200
    }
}
```

## Get user bet record 2

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getRecordByTime?startTime={startTime}&endTime={endTime}&pageIndex={pageIndex}&pageSize={pageSize}&version={version}`

**Describe**:<p>For access party calls,Get bets by time period[getRecordByTime],All bets within this time period will be returned in paginated form,The first page number starts from 1,The total number of items in this time period will be returned each time. This interface is only allowed to be called 10 times every 10 seconds. A maximum of 200 pieces of data are returned each time.</p>

**Request parameters**:

| Name      | Description                                                  | Type   | Describe     | Need  |
| --------- | ------------------------------------------------------------ | ------ | ------------ | ----- |
| startTime | Start time,date format "yyyy-MM-dd HH:mm:ss"<br/>Supports data for the latest month,<br/> spaces need to be escaped as %20 | string | start time   | true  |
| endTime   | End time,date format "yyyy-MM-dd HH:mm:ss"<br/>Start time~End time range within 24 Hour,<br/> spaces need to be escaped as %20 | string | end time     | true  |
| agentName | agent name                                                   | string | agent name   | false |
| pageIndex | page number                                                  | int    | page number  | true  |
| pageSize  | size of page,default 100,range 0~200                         | int    | size of page | false |
| version   | version，default value 3.0：Live video bet record，3.1：Live video、Live broadcast、 Block chain bet record、Chess bet record、 fishing bet record | string | version      | false |

**Response parameters**:

| Name    | Description                                              | Type   | Describe                                     |
| ------- | -------------------------------------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code)                                | int    | 0 indicates success, others indicate failure |
| message | message                                                  | string |                                              |
| value   | [game records](#Detailed explanation of Bet slip fields) | bets   | bet records                                  |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "gameRecords": [
            {
                "id": 415,
                "userName": "DT6501050d0dbe5769a97cad88",
                "channel": "DT",
                "agent": "621829689c133400019eb38d",
                "createTime": "2023-09-13 08:42:27",
                "gameType": 1,
                "tableId": "41",
                "roundId": "60749966",
                "betAmount": 10.0,
                "validBetAmount": 10.0,
                "betPoint": "PLAYER:10.00@10.00@10.00#",
                "odds": null,
                "money": 10.0,
                "serviceMoney": null,
                "beginTime": "2023-09-13 08:41:52",
                "endTime": "2023-09-13 08:42:47",
                "groupFor": "2023-09-12",
                "isBanker": 0,
                "gameInfo": "12-3-0;6-3-1;7-2-2;4-2-3;0-0-4;2-3-5",
                "gameResult": "PLAYER",
                "beforeBalance": null,
                "status": "A",
                "info1": null,
                "jp": 0,
                "enterType": 0,
                "shoeNum": 18,
                "gamblingNum": 19,
                "ip": "18.139.29.99",
                "currency": "CNY",
                "recordId": 1527397,//version 3.1
                "playType": 1 //version 3.1
            }
        ],
        "lastRecordId": 5962,
        "total": 1,
        "pageIndex": 1,
        "currPageSize": 1,
        "pageSize": 200
    }
}
```

## Get user bet record 3(Video games, live streaming games, Block chain games, Board game, fishing games)

**Request method**:`GET`

**Address**:`https://<server>/channelApi/V3/API/{channel}/getRecordByMaxId?maxRecordId={maxRecordId}&type={type}&pageIndex={pageIndex}&pageSize={pageSize}`

**Describe**:<p>For the access party to call, get the bet orders according to the maximum ID [getRecordByMaxId]. All bet orders will be returned in a paging manner. The first page number starts from 1, and the total number of items in this time period will be returned each time. This interface only allows 10 seconds Called 10 times, a maximum of 200 pieces of data will be returned each time.maxRecordId is the recordId of the last piece of data pulled, and maxRecordId needs to be updated each time a bet is pulled within the same period.</p>

**Request parameters**:

| Name        | Description                                                  | Type | Describe     | Need  |
| ----------- | ------------------------------------------------------------ | ---- | ------------ | ----- |
| maxRecordId | Record ID                                                    | long | Record ID    | true  |
| type        | Type: default 0, range 0~5, 0-all, 1-Live video, 2-live, 3-Block chain, 4-cards, 5-fishing | int  | type         | false |
| pageIndex   | page number                                                  | int  | page number  | true  |
| pageSize    | size of page,default 100,range 0~200                         | int  | size of page | false |

**Response parameters**:

| Name    | Description                                              | Type   | Describe                                     |
| ------- | -------------------------------------------------------- | ------ | -------------------------------------------- |
| state   | [State code](#State code)                                | int    | 0 indicates success, others indicate failure |
| message | message                                                  | string |                                              |
| value   | [game records](#Detailed explanation of Bet slip fields) | bets   | bet records                                  |

**Response example**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "gameRecords": [
            {
                "recordId": 1568487,
                "id": 1714485061983433,
                "userName": "SWu1LxXc",
                "channel": "SW",
                "agent": "SW-AGENT",
                "createTime": "2024-04-30 21:50:34",
                "gameType": 6333,
                "tableId": "10246",
                "roundId": "180260",
                "betAmount": 10.0,
                "validBetAmount": 10.0,
                "betPoint": "骰宝币安链",
                "money": 120.0,
                "beginTime": "2024-04-30 21:51:01",
                "endTime": "2024-04-30 21:51:01",
                "groupFor": "2024-04-30",
                "status": "A",
                "shoeNum": 0,
                "gamblingNum": 0,
                "currency": "CNY",
                "playType": 1 
            }
        ],
        "lastRecordId": 5962,
        "total": 1,
        "pageIndex": 1,
        "currPageSize": 1,
        "pageSize": 200
    }
}
```

## Detailed explanation of Bet slip fields

| Name           | Type     | Describe                                                                                                                                                                                                                                                                                                                                    |
| -------------- | -------- |---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| id             | int      | bet id                                                                                                                                                                                                                                                                                                                                      |
| status         | string   | list state,A: Already Payout B: Not settle(Abnormal) C: Bet cancel                                                                                                                                                                                                                                                                          |
| userName       | string   | user name                                                                                                                                                                                                                                                                                                                                   |
| channel        | string   | channel number                                                                                                                                                                                                                                                                                                                              |
| agent          | string   | agent number                                                                                                                                                                                                                                                                                                                                |
| createTime     | datetime | the creation time is Beijing time (yyyy-MM-dd HH:mm:ss)                                                                                                                                                                                                                                                                                     |
| groupFor       | date     | Shift number, for example, 2024-05-31 12:00:00 ~ 06-01 12:00:00, the shift number is 2024-05-31                                                                                                                                                                                                                                             |
| gameType       | int      | 【Casino Game Type】Baccarat:1 、Dragon Tiger: 2 、Roulette: 3 、Sic Bo: 4 、Bull Bull:5 、Win3Cards:12<br/>【Blockchain Game Type】Baccarat :1000 、Dragon Tiger:1001、21 Blackjack:1002、Digital Hash:1003、<br/>Two-tailed hash:1004、Golden Flower:1005、Niu Niu:1006、Lucky Texas:1007、Roulette:1008、Sic Bo:1009、<br/>BASE Jump :2000、BASE Jump 2:2001 |
| tableId        | string   | table number                                                                                                                                                                                                                                                                                                                                |
| roundId        | string   | round id                                                                                                                                                                                                                                                                                                                                    |
| betAmount      | double   | betting amount, unit is Chinese Yuan                                                                                                                                                                                                                                                                                                        |
| validBetAmount | double   | effective bet amount, unit is Chinese Yuan                                                                                                                                                                                                                                                                                                  |
| betPoint       | string   | betting point, it is recommended to reserve 2000 bytes                                                                                                                                                                                                                                                                                      |
| odds           | double   | odds(double number)                                                                                                                                                                                                                                                                                                                         |
| money          | double   | win Loss amount                                                                                                                                                                                                                                                                                                                             |
| currency       | string   | currency unit                                                                                                                                                                                                                                                                                                                               |
| serviceMoney   | double   | service fee(tip)                                                                                                                                                                                                                                                                                                                            |
| beginTime      | string   | the game start time is Beijing time(yyyy-MM-dd HH:mm:ss)                                                                                                                                                                                                                                                                                    |
| endTime        | string   | the game ends time is Beijing time(yyyy-MM-dd HH:mm:ss)                                                                                                                                                                                                                                                                                     |
| isBanker       | int      | Deprecated fields,banker or Player Banker is 1  Player is 0                                                                                                                                                                                                                                                                                 |
| gameInfo       | string   | dealing situation,Recommend to reserve 1000 bytes                                                                                                                                                                                                                                                                                           |
| gameResult     | string   | game lottery result                                                                                                                                                                                                                                                                                                                         |
| jp             | int      | betting method: 0 means non-commission-free, 1 means commission-free, only effective for Baccarat (banker) betting points                                                                                                                                                                                                                   |
| info1          | string   | extra field 1,Default is empty, Value depends on game,recommended to reserve 1000 bytes                                                                                                                                                                                                                                                     |
| shoeNum        | int      | number of shoe                                                                                                                                                                                                                                                                                                                              |
| gamblingNum    | int      | number of game                                                                                                                                                                                                                                                                                                                              |
| enterType      | int      | Betting methods: 1 Lobby 2 Table changing list 3 Multiple tables 4 Tables within the table (enter the table)                                                                                                                                                                                                                                |
| ip             | string   | The client IP address when the player places a bet                                                                                                                                                                                                                                                                                          |
| recordId       | long     | Field reserved for third-party games, record ID（V3.1）                                                                                                                                                                                                                                                                                       |
| playType       | int      | Game type, 1: Live video 2: Live broadcast 3: Block chain 4: Chess and Cards 5: Fishing（V3.1）                                                                                                                                                                                                                                               |

## **Baccarat**

**gameInfo Parsing instructions**

Baccarat gameInfo has recorded dealing information,each card is separated by“;”, Player card dealt first,then banker. The example is as follows:

```
3-3-0;6-2-1;5-2-2;11-1-3;0-0-4;0-0-5
```

**Field Parsing instructions**

| example:11-1-3 | parsing              | Description                                                  |
| -------------- | -------------------- | ------------------------------------------------------------ |
| 11             | J                    | card value(1,2,3,4,5,6,7,8,9,10,11,12,13),0 means invalid and does not exist |
| 1              | SPADE                | the suit of the card (1 SPADE, <br/> 2 HEART,3 CLUB,4 DIAMOND),0 means invalid and does not exist |
| 3              | Banker's second card | the position of the card, used to distinguish banker and player cards.<br/> player's first card is 0, banker's first card is 1, player's second card is 2,<br/> banker's second card is 3, player's third card is 4,banker's third card<br/> is 5. |

**gameResult Parsing instructions**

Baccarat gameResult has recorded the winning bet point Examples are as follows:

```
BANKER
```

**Field Parsing instructions**

| Name   | example | Description                                                  |
| ------ | ------- | ------------------------------------------------------------ |
| BANKER | BANKER  | banker player wins the betting point(BANKER: banker,PLAYER : player,TILE: tie) |

**betPoint Parsing instructions**

Baccarat records users’ betting and winning information, examples are as follows:

```
PLAYER:3000.00@0.00@0.00#
```

Corresponding example Parsing instructions:

Betting point name: Bet amount@Win/Loss Amount@Chip amount#,Many betting point use"#"segmentation

| Name   | example | Description                                                  |
| ------ | ------- | ------------------------------------------------------------ |
| BANKER | BANKER  | banker player wins the betting point(BANKER: banker,PLAYER : player,TILE: tie) |
| PP     | PP      | odd and even pairs (BP: Banker pair, PP: Player pair, BO: Banker single, BE: Banker double, PO: Player single, PE: Player double, SS: Super six,LS: Lucky six) |
| SMALL  | SMALL   | big small(BIG,SMALL)                                         |
| BN     | BN      | banker natural                                               |
| PN     | PN      | player natural                                               |
| AP     | AP      | either pair                                                  |
| PFP    | PFP     | perfect pair                                                 |
| BDB    | BDB     | banker dragon bonus                                          |
| PDB    | PDB     | player dragon bonus                                          |

## Dragon Tiger

**gameInfo Parsing instructions**

Dragon Tiger’s gameInfo has recorded dealing information, Fields are separated by ";", Examples are as follows:

```
10-2-0;7-2-1
```

**Field Parsing instructions**

| example:10-2-0 | parsing                | Description                                                  |
| -------------- | ---------------------- | ------------------------------------------------------------ |
| 10             | 10                     | card value(1,2,3,4,5,6,7,8,9,10,11,12,13)                    |
| 2              | HEART                  | the suit of the card (1 SPADE, 2 HEART, 3 CLUB,<br/>4 DIAMOND) |
| 0              | The first card (Tiger) | the position of the card (Tiger 0; Dragon 1)                 |

**gameResult Parsing instructions**

Dragon Tiger’s gameResult has recorded the winning betting point, Examples are as follows:

```
BANKER
```

**Field Parsing instructions**

| Name   | Example | Description                                                  |
| ------ | ------- | ------------------------------------------------------------ |
| BANKER | BANKER  | dragon Tiger’s winning betting point (BANKER: dragon,PLAYER: tiger,TILE: tie) |

**betPoint Parsing instructions**

Dragon Tiger’s bet Point has recorded user’s bet amount and win/loss amount, examples are as follows:

```
PLAYER:3000.00@0.00@0.00#
```

Corresponding example parsing instructions:

Betting point name: Betting amount@win/loss amount@Chip amount#,Many betting point use"#"segmentation

## **Bull bull**

**gameInfo Parsing instructions**

Bull bull’s gameInfo has recorded dealing information, fields are separated by ";", examples are as follows:

```
13-1-0;9-1-1;8-4-2;8-3-3;2-2-4;4-4-5;10-2-6;6-3-7;12-4-8;9-4-9;2-1-10;10-3-11;4-1-12;3-4-13;8-2-14;2-4-15;6-4-16;5-3-17;10-1-18;7-3-19;7-1-20
```

**Field Parsing instructions**

| example:10-2-0 | parsing  | Description                                                  |
| -------------- | -------- | ------------------------------------------------------------ |
| 10             | 10       | card value (1,2,3,4,5,6,7,8,9,10,11,12,13)                   |
| 2              | HEART    | the suit of the card (1 SPADE, 2 HEART, 3 CLUB,<br/>4 DIAMOND) |
| 0              | Top card | Card position (top card 0, banker, 1-5, player 1, 6-10, <br/>player 2, 11-15, player 3, 16-20) |

**gameResult Parsing instructions**

Bull bull’s gameResult has recorded the winning betting point, Examples are as follows:

```
[{\"fullNiu\":false,\"hasNiu\":true,\"niuIndex\":[1,2,4],\"point\":1,\"ratio\":0.0},{\"fullNiu\":false,\"hasNiu\":false,\"niuIndex\":[],\"point\":0,\"ratio\":-1.0,\"win\":false},{\"fullNiu\":false,\"hasNiu\":true,\"niuIndex\":[0,3,4],\"point\":7,\"ratio\":1.9,\"win\":true},{\"fullNiu\":false,\"hasNiu\":true,\"niuIndex\":[0,3,4],\"point\":5,\"ratio\":0.95,\"win\":true}]
```

**Field Parsing instructions**

| Name     | example | Description                                                  |
| -------- | ------- | ------------------------------------------------------------ |
| fullNiu  | false   | is it full bull                                              |
| hasNiu   | true    | is there bull                                                |
| point    | 1       | point                                                        |
| win      | true    | true win false lose                                          |
| niuIndex | 1,2,4   | a certain banker or player ‘s 5 card subscript,These 3 cards<br> combinate to a bull |
| ratio    | 1.9     | odds, positive number means winning, negative number<br/> means losing |

**betPoint Parsing instructions**

Bull bull betPoint has recorded user’s bet amount and winning or losing amount, examples are as follows:

```
PLAYER1:1000.00@-1000.00@1000.00
```

Corresponding example analysis instructions:

Betting point name: Betting amount@win/loss amount@Chip amount#,Many betting point use"#"segmentation

**Field Parsing instructions**

| Name              | example           | Description             |
| ----------------- | ----------------- | ----------------------- |
| PLAYER1           | PLAYER1           | player 1 equal          |
| PLAYER2           | PLAYER2           | player 2 equal          |
| PLAYER3           | PLAYER3           | player 3 equal          |
| FAN_PLAYER1       | FAN_PLAYER1       | player 1 double         |
| FAN_PLAYER2       | FAN_PLAYER2       | player 2 double         |
| FAN_PLAYER3       | FAN_PLAYER3       | player 3 double         |
| YAJIN_FAN_PLAYER1 | YAJIN_FAN_PLAYER1 | player 1 double deposit |
| YAJIN_FAN_PLAYER2 | YAJIN_FAN_PLAYER2 | player 2 double deposit |
| YAJIN_FAN_PLAYER3 | YAJIN_FAN_PLAYER3 | player 3 double deposit |

## **Roulette**

**gameInfo Parsing instructions**

Roulette’s gameInfo has recorded dealing information, Fields are separated by ";", Examples are as follows:

```
1
```

**Field Parsing instructions**

| example:1 | Parsing          | Description                         |
| --------- | ---------------- | ----------------------------------- |
| 1         | Lottery points 1 | the lottery points are from 0 to 36 |

**gameResult Parsing instructions**

Roulette gameResult has recorded the winning betting point,examples are as follows:

```
1
```

**Field Parsing instructions**

| Name       | Example | Description      |
| ---------- | ------- | ---------------- |
| gameResult | 1       | lottery points 1 |

**betPoint Parsing instructions**

Roulette betPoint has recorded user’s bet amount and winning or losing amount, examples are as follows:

```
RoSm:100.00@100.00@100.00#RoDu12:100.00@1700.00@100.00#RoOdd:100.00@100.00@100.00#Ro12s1:100.00@200.00@100.00#Ro1245:100.00@800.00@100.00#RoDu14:100.00@1700.00@100.00#RoSi01:100.00@3500.00@100.00#RoRed:100.00@100.00@100.00#
```

Corresponding example parsing instructions:

Betting point name: Betting amount@win/loss amount@Chip amount#,Many betting point use"#"segmentation

**Betting point details:**

| Name        | Description                                                  |
| ----------- | ------------------------------------------------------------ |
| Odd even    | RoOdd: Odd, RoEven: Even                                     |
| Black red   | RoBak: Black, RoRed: Red                                     |
| Big small   | RoBig: Big, RoSm: Small                                      |
| dozen bet   | Ro12s1: 1st dozen,Ro12s2: 2nd dozen,Ro12s3: 3rd dozen        |
| Row bet     | RoRow1: RoRow1:1st row,RoRow2:2nd row,RoRow3:3rd row         |
| Column bet  | RoCol1,RoCol2, RoCol3,RoCol4,RoCol5,RoCol6,RoCol7,<br>RoCol8,RoCol9,RoCol0,RoCola |
| Direct bet  | RoSi01,RoSi02,RoSi03,RoSi04,RoSi05,RoSi06,RoSi07, <br/>RoSi08,RoSi09,RoSi10,RoSi11,RoSi12,RoSi13,RoSi14, <br/>RoSi15,RoSi16,RoSi17,RoSi18,RoSi19,RoSi20,RoSi21,<br/>RoSi22,RoSi23,RoSi24,RoSi25,RoSi26,RoSi27,RoSi28, <br/>RoSi29,RoSi30,RoSi31,RoSi32,RoSi33,RoSi34,RoSi35, <br/>RoSi36,RoSi88 |
| Split bet   | RoDu12,RoDu23,RoDu36,RoDu14,RoDu25,RoDu45,RoDu56,<br/> RoDu47,RoDu58,RoDu69,RoDu78,RoDu89,RoDu70,RoDu8a, <br/>RoDu9b,RoDu0a,RoDuab,RoDu0c,RoDuad,RoDube,RoDucd,<br/> RoDude,RoDucf,RoDudg,RoDueh,RoDufg,RoDugh,RoDufi, <br/>RoDugj,RoDuhk,RoDuij,RoDujk,RoDuil,RoDujm,RoDukn, <br/>RoDulm,RoDumn,RoDulo,RoDump,RoDunq,RoDuop,RoDupq,<br/> RoDuor,RoDups,RoDuqt,RoDurs,RoDust,RoDuru,RoDusv,RoDutw,<br/> RoDuuv,RoDuvy,RoDuwz,RoDuxy,RoDuyz,RoDu_1,RoDu_2,<br/> RoDu_3,RoDuux,RoDuvw |
| Three Bet   | RoT_12,RoT_23                                                |
| Street Bet  | RoT123,RoT456,RoT789,RoT0ab,RoTcde,RoTfgh,RoTijk,RoTlmn,<br/> RoTopq,RoTrst,RoTuvw,RoTxyz |
| Four bet    | Ro_123                                                       |
| Corner note | Ro1245,Ro2356,Ro5689,Ro4578,Ro89ab,Ro780a,Ro0acd,<br/> Roabde,Rocdfg,Rodegh,Rofgij,Roghjk,Roijlm,Rojkmn, <br/>Romnpq,Rooprs,Ropqst,Rorsuv,Rostvw,Rouvxy,Rovwyz ,Rolmop |

**Corresponding text Describe**

RoEven = Even;RoOdd = Odd;Ro12s1 = 1st dozen;Ro12s2 = 2nd Dozen;Ro12s3 = 3rd dozen;RoRow1 = 1st row;RoRow2 = 2nd row;RoRow3 = 3rd row;RoSm = small;RoBig = big;RoSm1 = small  1-18 ;RoBig1 = big 19-36;RoBak = black;RoRed = red;RedBak = red / black;BigSm = big / small;TaxiList = dozen / row;OddEven = odd / even;Direct_Bet = Direct bet;Marks_Bet = Split bet;Street_Bet = Street bet;Three_Several = Three bet;Corner_Bet = Conner bet;Four_Bet = Four bet;Line_Bet = Column bet;Make_Bet = Row bet;Bet_Dozen = Bet dozen;RoSi88 = Direct bet 0;RoSi01 = Direct bet 1;RoSi02 = Direct bet2;RoSi03 = Direct bet3;RoSi04 = Direct bet 4;RoSi05 = Direct bet 5;RoSi06 = Direct bet 6;RoSi07 = Direct bet7;RoSi08 = Direct bet 8;RoSi09 = Direct bet 9;RoSi10 = Direct bet 10;RoSi11 = Direct bet 11;RoSi12 = Direct bet 12;RoSi13 = Direct bet 13;RoSi14 = Direct bet 14;RoSi15 = Direct bet15;RoSi16 = Direct bet 16;RoSi17 = Direct bet 17;RoSi18 = Direct bet 18;RoSi19 = Direct bet 19;RoSi20 = Direct bet 20;RoSi21 = Direct bet 21;RoSi22 = Direct 22;RoSi23 = Direct 23;RoSi24 = Direct 24;RoSi25 = Direct 25;RoSi26 = Direct 26;RoSi27 = Direct27;RoSi28 = Direct28;RoSi29 = Direct 29;RoSi30 = Direct 30;RoSi31 = Direct 31;RoSi32 = Direct 32;RoSi33 = Direct 33;RoSi34 = Direct 34;RoSi35 = Direct 35;RoSi36 = Direct 36;RoT_12 = Three bet 0,1,2;RoT_23 = Three bet 0,2,3;Ro_123 = Four bet0,1,2,3;RoCol1 = Column bet 1,2,3,4,5,6;RoCol2 = Column bet 4,5,6,7,8,9 ;RoCol3 = Column bet 7,8,9,10,11,12;RoCol4 = Column bet 10,11,12,13,14,15;RoCol5 = Column bet 13,14,15,16,17,18;RoCol6 = Column bet 16,17,18,19,20,21;RoCol7 = Column bet 19,20,21,22,23,24;RoCol8 = Column bet 22,23,24,25,26,27;RoCol9 = Column bet 25,26,27,28,29,30;RoCol0 = Column bet28,29,30,31,32,33;RoCola = Column bet 31,32,33,34,35,36;Ro1245 = Conner bet 1,2,4,5;Ro2356 = Conner bet 2,3,5,6;Ro4578 = Conner bet 4,5,7,8;Ro5689 = Conner bet 5,6,8,9;Ro780a = Conner bet 7,8,10,11;Ro89ab = Conner bet8,9,11,12;Ro0acd = Conner bet 10,11,13,14;Roabde = Conner bet 11,12,14,15;Rocdfg = Conner bet 13,14,16,17;Rodegh = Conner bet 14,15,17,18;Rofgij = Conner bet 16,17,19,20;Roghjk = Conner bet 17,18,20,21;Roijlm = Conner bet 19,20,22,23;Rojkmn = Conner bet 20,21,23,24;Rolmop = Conner bet 22,23,25,26;Romnpq = Conner bet 23,24,26,27;Rooprs = Conner bet 25,26,28,29;Ropqst = Conner bet 26,27,29,30;Rorsuv = Conner bet 28,29,31,32;Rostvw = Conner bet 29,30,32,33;Rouvxy = Conner bet 31,32,34,35;Rovwyz = Conner bet 32,33,35,36;RoT123 = Street bet 1,2,3 ;RoT456 = Street bet 4,5,6;RoT789 =Street bet 7,8,9;RoT0ab =Street bet 10,11,12;RoTcde = Street bet 13,14,15;RoTfgh = Street bet 16,17,18;RoTijk = Street bet 19,20,21;RoTlmn = Street bet 22,23,24;RoTopq = Street bet 25,26,27;RoTrst = Street bet 28,29,30;RoTuvw = Street bet31,32,33;RoTxyz = Street bet 34,35,36;RoDu12 = Split bet1,2;RoDu23 = Split bet 2,3;RoDu45 = Split bet4,5;RoDu56 =Split bet5,6;RoDu78 = Split bet7,8;RoDu89 = Split bet8,9;RoDu0a = Split bet10,11;RoDuab = Split bet11,12;RoDucd = Split bet13,14;RoDude =Split bet14,15;RoDufg = Split bet16,17;RoDugh = Split bet17,18;RoDuij = Split bet19,20;RoDujk = Split bet20,21;RoDulm = Split bet22,23;RoDumn = Split bet23,24;RoDuop = Split bet25,26;RoDupq = Split bet26,27;RoDurs = Split bet28,29;RoDust = Split bet29,30;RoDuuv = Split bet31,32;RoDuvw = Split bet32,33;RoDuxy = Split bet34,35;RoDuyz = Split bet35,36;RoDu_1 =Split bet0,1;RoDu_2 = Split bet0,2;RoDu_3 = Split bet0,3;RoDu14 = Split bet1,4;RoDu25 = Split bet2,5;RoDu36 = Split bet3,6;RoDu47 = Split bet4,7;RoDu58 = Split bet5,8;RoDu69 = Split bet6,9;RoDu70 = Split bet7,10;RoDu8a = Split bet8,11;RoDu9b = Split bet9,12;RoDu0c = Split bet10,13;RoDuad = Split bet11,14;RoDube = Split bet12,15;RoDucf = Split bet13,16;RoDudg = Split bet14,17;RoDueh = Split bet15,18;RoDufi = Split bet16,19;RoDugj = Split bet17,20;RoDuhk = Split bet18,21;RoDuil = Split bet19,22;RoDujm = Split bet20,23;RoDukn = Split bet21,24;RoDulo = Split bet22,25;RoDump = Split bet23,26;RoDunq = Split bet24,27;RoDuor = Split bet25,28;RoDups = Split bet26,29;RoDuqt = Split bet27,30;RoDuru = Split bet28,31;RoDusv =Split bet29,32;RoDutw = Split bet30,33;RoDuux = Split bet31,34;RoDuvy = Split bet32,35;RoDuwz = Split bet33,36;

## **Sic bo**

**gameInfo Parsing instructions**

Sic bo gameInfo has recorded dealing information, Fields are separated by ";", Examples are as follows:

```
1;2;3
```

**Field Parsing instructions**

| example | Parsing | Description                                  |
| ------- | ------- | -------------------------------------------- |
| 1;2;3   | 1;2;3   | the lottery dice is :1 point,2 point,3 point |

**gameResult Parsing instructions**

Sic bo gameResult has recorded the winning betting point,examples are as follows: same gameInfo

```
1;2;3
```

**betPoint Parsing instructions**

Sic bo betPoint has recorded user’s bet amount and winning or losing amount, examples are as follows:

```
DiSm:1000.00@1000.00@1000.00#
```

Corresponding example Parsing instructions:

Betting point name: Betting amount@win/loss amount@Chip amount#,Many betting point use"#"segmentation

**Betting point details:**

| Name          | Description                        |
| ------------- | ---------------------------------- |
| DiTri0        | full range dice                    |
| DiTri1~DiTri6 | dice1 to dice6                     |
| DiDou1~DiDou6 | double 1 to double 6               |
| DiTo04~DiTo17 | 4 total to 17 total                |
| DiTw12~DiTw16 | combination 1-2 to combination 1-6 |
| DiTw23~DiTw26 | combination 2-3 to combination 2-6 |
| DiTw34~DiTw36 | combination 3-4 to combination 3-6 |
| DiTw45~DiTw46 | combination 4-5 to combination 4-6 |
| DiTw56        | combination 5-6                    |
| DiOne1~DiOne6 | single 1 to single 6               |
| DiEven        | even                               |
| DiOdd         | odd                                |
| DiBig         | big                                |
| DiSm          | small                              |

## **WIN3CARDS**

**gameInfo Parsing instructions**

win3cards game Info of the game records the card dealing information, and the fields are separated by ";",The example is as follows:

```
2-3-0;5-2-1;2-2-2;5-4-3;5-3-4;11-3-5
```

**Field Parsing instructions**

| example:2-3-0 | Parsing             | Description                                            |
| ------------- | ------------------- | ------------------------------------------------------ |
| 2             | 2                   | The number of cards(1,2,3,4,5,6,7,8,9,10,11,12,13)     |
| 3             | CLUB                | Suit of the card (1 SPADE, 2 HEART, 3 CLUB, 4 DIAMOND) |
| 0             | First Card (Dragon) | Card position (Dragon 0,2,4; Phoenix 1,3,5)            |

**gameResult Parsing instructions**

win3cards game gameResult has recorded the winning betting point, Examples are as follows:

```
PHOENIX
```

**Field parsing instructions**

| Name    | Example | Description                                                  |
| ------- | ------- | ------------------------------------------------------------ |
| PHOENIX | PHOENIX | Dragon and Phoenix (DRAGON: Dragon, PHOENIX: Phoenix, TILE: He) |

**betPoint Parsing instructions**

win3cards  betPoint records the user's betting amount and winning and losing amount, as shown below:

```
PHOENIX:10.00@9.50@9.50#DRAGON:10.00@-10.00
```

Corresponding example analysis explanation:

Betting point name: betting amount@win/loss amount@washing amount#, use "#" to separate multiple betting points

**Betting point details:**

| Name           | Description    |
| -------------- | -------------- |
| PHOENIX        | PHOENIX        |
| DRAGON         | DRAGON         |
| PAIR8          | PAIR8          |
| FLUSH          | FLUSH          |
| STRAIGHT       | STRAIGHT       |
| BOMB           | BOMB           |
| STRAIGHT_FLUSH | STRAIGHT_FLUSH |

## HTTP State code

| CODE | MESSAGE                   | MESSAGE-EN  |
| :--- | ------------------------- | ----------- |
| 200  | Success                   | Success     |
| 400  | Parameters do not match   | Bad Request |
| 403  | Token verification failed | UnAuth      |

## State code

| CODE   | MESSAGE                                           | MESSAGE-EN                 |
|:-------|---------------------------------------------------| -------------------------- |
| 0      | Success                                           | Success                    |
| -101   | Account is deactivated                            | Account Stop               |
| 202    | Channel does not match                            | Invalid Channel            |
| 400    | Parameters do not match                           | Bad Request                |
| 500    | Server error                                      | Server error               |
| 602    | User already exists                               | User Exists                |
| 603    | User status is wrong                              | Invalid User Status        |
| 624    | Insufficient balance                              | Lack Of Balance            |
| 627    | Duplicate order number                            | Serial Repeat              |
| 630    | Data expired                                      | Data Expired               |
| 631    | Username contains keywords                        | Username contains keywords |
| 1001   | Record does not exist                             | Record not exists          |
| 1002   | User does not exist                               | User does not exist        |
| 100000 | User is not registered                            | User no register           |
| 100004 | The game is not activated                         | Game closed                |
| 100005 | Frequently call                                   | FREQUENTLY_CALL            |
| 100006 | Too many logins in a short period of time         | FREQUENTLY_LOGIN           |
| 100007 | Server is busy                                    | SERVER_BUSY                |
| 100008 | Duplicate agent name                              | AGENT_NAME_REPEAT          |
| 100012 | This currency is not supported                    | CURRENCY_NOT_SUPPORT       |
| 100019 | The agent name does not exist                     | AGENT_NOT_EXIST            |
| 100020 | The agent does not match the channel              | AGENT_COMPANY_MATCH        |
| 100021 | The amount is too large and exceeds the threshold | AMOUNT_GREATER             |
| 100022 | Users can select up to 3 quotas                   | LIMIT_GREATER              |
| 100023 | quotas code error                                 | LIMIT_CODE_ERROR           |

## CURRENCY

| Code   | Type                 |
| :----- | -------------------- |
| CNY    | Chinese Yuan         |
| USD    | United State Dollar  |
| KRW    | Korean Won           |
| HKD    | Hong Kong Dollar     |
| AUD    | Australian Dollar    |
| THB    | Thai Baht            |
| VND    | Vietnamese Dong      |
| VND(K) | Vietnamese Dong(K)   |
| IDR    | Indonesian Rupiah    |
| IDR(K) | Indonesian Rupiah(K) |
| MYR    | Malaysian Ringgit    |
| INR    | Indian Rupees        |
| MMK    | Myanmar Kyat         |
| KES    | Kenyan Shilling      |
| USDT   | Tether               |
| mETH   | ETH                  |
| mBTC   | BTH                  |
| BDT    | Bangladeshi Taka     |
| PHP    | Philippine Peso      |
| GBP    | Pound Sterling       |
| AED    | Dirham               |
| TWD    | New Taiwan Dollar    |
| PKR    | Pakistani Rupee      |
| MXN    | mexican dollar       |
| BRL    | Brazilian currency   |
| SGD    | Singapore Dollar     |
| CLP    | Chilean Peso         |
| PEN    | Peruvian Sol         |
| VES    | Venezuelan Bolívar   |
| HNL    | Honduran Lempira     |
| CRC    | Costa Rican Colon    |
| GTQ    | Guatemalan Quetzal   |
| TZS    | Tanzanian Shilling   |
